-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_10:StartActivity()
	print("START! -- MissionTutorial_10:StartActivity()!");
	
	self.braindead = {};
	self.AssignedBrains = {};
	self.MOIDLimit = 120;

	self.Zone = SceneMan.Scene:GetArea("MissionTut_10_Area");
    
	-- Create timers which will countdown spawn intervals for dummies and coalition
	self.SpawnTimer = Timer();
	
	self.SpawnInterval = 1000;
	
	self.TechIDs = {}
	
   	-- Set up players
	for team = 0, Activity.MAXTEAMCOUNT - 1 do
		if self:TeamActive(team) then
			-- Enable fog of war for every team if fog of war flag was checked
			if self:GetFogOfWarEnabled() then
				SceneMan:MakeAllUnseen(Vector(25, 25), team)
			end
			-- Read Tech selection from scenario setup dialog
			self.TechIDs[team] = PresetMan:GetModuleID(self:GetTeamTech(team))
			
			-- Set CPU gold to zero, and player gold to whatever was selected in scenario setup dialog
			if self:TeamIsCPU(team) then
				self:SetTeamFunds(0 , team);
			else
				self:SetTeamFunds(self:GetStartingGold() , team);
			end
		end
    end
	
	-- We'll send actors right to THE SEAM OF DEATH. But now it's safe, because it's just the seam now, not of death. But not of life either.
	self.SceneMid = SceneMan:MovePointToGround(Vector(0, 0) , 10 , 3);

    for actor in MovableMan.AddedActors do
		actor.AIMode = Actor.AIMODE_SENTRY;
    end
	
	-- Reset timers to avoid unexpected behaviour on activity restart
	self.SpawnTimer:Reset();
end
-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------
-- This function is called when mission is paused
function MissionTutorial_10:PauseActivity(pause)
    print("PAUSE! -- MissionTutorial_10:PauseActivity()!");
end
-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------
-- This function is called after mission has ended
function MissionTutorial_10:EndActivity()
    print("END! -- MissionTutorial_10:EndActivity()!");
end
-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_10:UpdateActivity()
   	-- Clear all objective markers, they get re-added each frame
   	self:ClearObjectivePoints();

	-- We don't have any phases here, just a sandbox combat so run single combat phase
	self:PhaseNoFight();
	
	self:YSortObjectivePoints();
end
-----------------------------------------------------------------------------------------
-- Phase "No fight"
-----------------------------------------------------------------------------------------
function MissionTutorial_10:SpawnClone(team)
	local actor
	local weapon
	local grenade
	
	-- Most new vanilla activities rely on a set of Random<EntityClass>(group, module) functions to create
	-- and spawn actors and weapons. For example RandomAHuman, RandomACrab, RandomHDFirearm, RandomTDExplosive
	--RandomACDropShip, RandomACRocket, CreateTerrainObject etc.
	
	-- Vanilla activities usually use this set of groups:
	-- Actors               All actors, including turrets, can be any class
	-- Craft				Crafts: ACRocket and ACDropShip classes
	-- Crates				Crates: ACRocket
	-- Anti-Air				Anti-Air drone: ACrab, but probably can be anything
	-- Diggers				Diggers: HDFirearm
	-- Explosive Weapons	Weapons which do explosive damage: HDFirearm
	-- Grenades				Grenades used by troops: TDExplosive
	-- Heavy Infantry		Heavy infantry: AHuman
	-- Light Infantry		Light infantry: AHuman
	-- Heavy Weapons		Heavy (in terms of weight, but also power) weapons: HDFirearm
	-- Light Weapons		Light weapons: HDFirearm
	-- Primary Weapons
	-- Secondary Weapons
	-- Mecha				Armoured robots: ACrab
	-- Payloads				Bombs dropped from drops hips: TDExplosive
	-- Shields				Shields, HeldDevice
	-- Sniper Weapons		Sniper rifles, HDFirearm
	-- Snipers				Snipers: AHuman
	-- Tools				Miscellaneous tools, including diggers
	-- Weapons				All weapons: HDFirearm
	-- Brains				Brain units: Actor, AHuman
	-- Any					Any group
	
	-- You can define your own groups, and request them but don't expect that others will support those groups too.
	
	-- Get crab to human ratio from tech module. Default value is 0.25. 
	-- You can add the property CrabToHumanSpawnRatio right to your module to set this value to whatever you want and even 0 if your tech don't provide any ACrabs.
	if math.random() >= self:GetCrabToHumanSpawnRatio(self.TechIDs[team]) then
		if math.random() < 0.35 then
			actor = RandomAHuman("Heavy Infantry", self.TechIDs[team]);
		else
			actor = RandomAHuman("Light Infantry", self.TechIDs[team]);
		end
		
		if actor then
			if math.random() < 0.4 then
				weapon = RandomHDFirearm("Heavy Weapons", self.TechIDs[team]);
			else
				weapon = RandomHDFirearm("Light Weapons", self.TechIDs[team]);
			end
			
			if math.random() < 0.4 then
				grenade = RandomTDExplosive("Grenade", self.TechIDs[team]);
			end
		end
	else
		actor = RandomACrab("Mecha", self.TechIDs[team]);
	end	
	
	-- Always check if actors and weapons were actually created!
	-- You must expect that some modules won't contain any objects in selected group, when it happens Random<Entity> returns 0.
	if actor then
		if weapon then
			actor:AddInventoryItem(weapon);
		end
		if grenade then
			actor:AddInventoryItem(grenade);
		end
		actor.Team = team;
		actor.AIMode = Actor.AIMODE_GOTO;
		actor:ClearAIWaypoints();
		actor:AddAISceneWaypoint(self.SceneMid);
		actor.Pos = SceneMan:MovePointToGround(Vector(math.random(SceneMan.Scene.Width), 0) , 10 , 3) + Vector(0,-15);
		MovableMan:AddActor(actor);
	end
end
-----------------------------------------------------------------------------------------
-- Phase "No fight"
-----------------------------------------------------------------------------------------
function MissionTutorial_10:PhaseNoFight()
	if self.SpawnTimer:IsPastSimMS(self.SpawnInterval) and MovableMan:GetMOIDCount() <= self.MOIDLimit then
		for team = 0, Activity.MAXTEAMCOUNT - 1 do
			-- Check if we already have a brain assigned
			if self:TeamActive(team) then
				self:SpawnClone(team);
			end
		end
		self.SpawnTimer:Reset();
		
		-- Spawn a bunker module as an example. You can access bunker module's sprite offset and size via
		-- TerrainObject:GetBitmapOffset()
		-- TerrainObject:GetWidth()
		-- TerrainObject:GetHeight()
		local obj = CreateTerrainObject("Closed Tomb", "Base.rte")
		if obj then
			obj.Pos = Vector(math.random(SceneMan.Scene.Width), math.random(SceneMan.Scene.Height))
			SceneMan:AddTerrainObject(obj)
		end		
		
	end
end
-----------------------------------------------------------------------------------------
-- That's all folks!
-----------------------------------------------------------------------------------------



































